summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
authorCraig Lafayette <craiglafa@google.com>2015-05-07 10:24:02 -0400
committerCraig Lafayette <craiglafa@google.com>2015-05-07 10:24:02 -0400
commit4e401fa49875e083d18b46e0250be37ad565071c (patch)
tree041b12e1444e73dd830c59cab8bf30146a8c926c /core
parentdbf62ace0dcb671f5eaa97c0dfa75e39bc9c88be (diff)
downloadframeworks_base-4e401fa49875e083d18b46e0250be37ad565071c.zip
frameworks_base-4e401fa49875e083d18b46e0250be37ad565071c.tar.gz
frameworks_base-4e401fa49875e083d18b46e0250be37ad565071c.tar.bz2
DevicePolicyManager API review changes
Renamed DO_NOT_ASK_CREDENTIALS_ON_BOOT to RESET_PASSWORD_DO_NOT_ASK_CREDENTIALS_ON_BOOT. Bug: 20820907 Change-Id: I6455f9a6d370afbd5154505f402b409dba3b7918
Diffstat (limited to 'core')
-rw-r--r--core/java/android/app/admin/DevicePolicyManager.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/java/android/app/admin/DevicePolicyManager.java b/core/java/android/app/admin/DevicePolicyManager.java
index 8009b6c..355f298 100644
--- a/core/java/android/app/admin/DevicePolicyManager.java
+++ b/core/java/android/app/admin/DevicePolicyManager.java
@@ -1653,9 +1653,9 @@ public class DevicePolicyManager {
}
/**
* Queries whether {@link #DO_NOT_ASK_CREDENTIALS_ON_BOOT} flag is set.
*
* @return true if DO_NOT_ASK_CREDENTIALS_ON_BOOT flag is set.
* @hide
*/
public boolean getDoNotAskCredentialsOnBoot() {
@@ -1753,7 +1753,7 @@ public class DevicePolicyManager {
* is ignored. Once the flag is set, it cannot be reverted back without resetting the
* device to factory defaults.
*/
- public static final int DO_NOT_ASK_CREDENTIALS_ON_BOOT = 0x0002;
+ public static final int RESET_PASSWORD_DO_NOT_ASK_CREDENTIALS_ON_BOOT = 0x0002;
/**
* Force a new device unlock password (the password needed to access the
@@ -1779,7 +1779,7 @@ public class DevicePolicyManager {
*
* @param password The new password for the user. Null or empty clears the password.
* @param flags May be 0 or combination of {@link #RESET_PASSWORD_REQUIRE_ENTRY} and
- * {@link #DO_NOT_ASK_CREDENTIALS_ON_BOOT}.
+ * {@link #RESET_PASSWORD_DO_NOT_ASK_CREDENTIALS_ON_BOOT}.
* @return Returns true if the password was applied, or false if it is
* not acceptable for the current constraints.
*/
@@ -1653,9 +1653,9 @@ public class DevicePolicyManager {
}
/**
- * Queries whether {@link #DO_NOT_ASK_CREDENTIALS_ON_BOOT} flag is set.
+ * Queries whether {@link #RESET_PASSWORD_DO_NOT_ASK_CREDENTIALS_ON_BOOT} flag is set.
*
@@ -1653,9 +1653,9 @@ public class DevicePolicyManager {
*
- * @return true if DO_NOT_ASK_CREDENTIALS_ON_BOOT flag is set.
+ * @return true if RESET_PASSWORD_DO_NOT_ASK_CREDENTIALS_ON_BOOT flag is set.
* @hide
*/